@@ -33,6 +33,12 @@ module Debci
       expand_template(:status_alerts, filename)
     end
 
+    def platform_specific_issues(filename)
+      @status_nav = load_template(:status_nav)
+      @issues = @repository.platform_specific_issues
+      expand_template(:platform_specific_issues, filename)
+    end
+
     def blacklist(filename)
       @status_nav = load_template(:status_nav)
       expand_template(:blacklist, filename)
@@ -50,6 +56,10 @@ module Debci
       expand_template(:packagelist, filename)
     end
 
+    def obsolete_packages_page(filename)
+      expand_template(:packages, filename)
+    end
+
     # expand { SUITE } macro in URLs
     def expand_url(url, suite)
       url && url.gsub('{SUITE}', suite)
