@@ -41,6 +41,7 @@ fi
 debci_distro_name="${debci_distro_name:-$(. /etc/os-release; echo ${NAME% *})}"
 debci_suite=${debci_suite:-unstable}
 debci_arch=${debci_arch:-$(dpkg --print-architecture)}
+debci_arch_list="${debci_arch_list:-${debci_arch}}"
 # debci-setup-chdist determines the default from debootstrap, don't set one here
 debci_mirror=
 debci_backend=${debci_backend:-lxc}
@@ -149,13 +150,15 @@ debci_amqp_queue=${debci_amqp_queue:-"debci-${debci_suite}-${debci_arch}-${debci
 
 debci_lock_dir=${debci_lock_dir:-/var/lock}
 
-# lock/timestamp files
+# per-suite/architecture lock/timestamp files
 debci_testbed_lock=${debci_lock_dir}/debci-testbed-${debci_suite}-${debci_arch}-${debci_backend}.lock
 debci_testbed_timestamp=${debci_lock_dir}/debci-testbed-${debci_suite}-${debci_arch}-${debci_backend}.stamp
 debci_chdist_lock=${debci_lock_dir}/debci-chdist-${debci_suite}-${debci_arch}.lock
-debci_generate_index_lock=${debci_lock_dir}/debci-generate-index-${debci_suite}-${debci_arch}.lock
 debci_batch_lock=${debci_lock_dir}/debci-batch-${debci_suite}-${debci_arch}.lock
 
+# global lock/timestamp files
+debci_generate_index_lock=${debci_lock_dir}/debci-generate-index.lock
+
 
 for dir in \
   "${debci_base_dir}/backends/${debci_backend}" \
