@@ -36,7 +36,7 @@ test_packages_without_runs_yet() {
   debci batch
   wait_for_results
   find $debci_data_basedir -type d -name rake | xargs rm -rf
-  debci generate-index
+  debci update
   find $debci_data_basedir -path '*data/status*' -name packages.json | xargs cat | json_pp -f json -t json > /dev/null
   assertEquals 0 $?
 }
