@@ -3,8 +3,8 @@
 mkdir -p data/autopkgtest-incoming/
 
 rerun -x \
-  --name debci-generate-index \
+  --name debci-update \
   --dir data/autopkgtest-incoming/ \
   --pattern '**/duration' \
   --background \
-  -- ./bin/debci generate-index
+  -- ./bin/debci update
